@@ -1,16 +1,25 @@
 from .openai import Openai
 from sparrow.api import create_app
-from fastapi import Request
+from fastapi import Request, APIRouter
 
-app = create_app(title="openai_forward", version="1.0")
+router = APIRouter()
 openai = Openai()
 
 
-@app.get("/dashboard/billing/credit_grants")
+@router.get("/dashboard/billing/credit_grants")
 async def credit_grants(request: Request):
     return await openai.credit_grants(request)
 
 
-@app.route("/v1/chat/completions", methods=["GET", "POST"])
+@router.route("/v1/chat/completions", methods=["GET", "POST"])
+async def completions_(request: Request):
+    return await openai.completions(request)
+
+
+@router.post("/v1/chat/completions")
 async def completions(request: Request):
     return await openai.completions(request)
+
+
+app = create_app(title="openai_forward", version="1.0")
+app.include_router(router, tags=["public"])
